@@ -1,9 +1,13 @@
+from __future__ import division, print_function, unicode_literals
+
 # This code is so you can run the samples without installing the package
 import sys
 import os
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
 #
 
+testinfo = "t 0.1, s, t 0.77, s, q"
+tags = "animation"
 
 import cocos
 from cocos.director import director
@@ -13,17 +17,18 @@ import pyglet
 class TestLayer(cocos.layer.Layer):
     def __init__(self):
         super( TestLayer, self ).__init__()
-        
-        x,y = director.get_window_size()
-        
-        self.sprite = Sprite(pyglet.resource.animation('dinosaur.gif'))
-        self.sprite.position = 0, y/2
-        self.add( self.sprite  )
-        
-        
 
-if __name__ == "__main__":
+        x,y = director.get_window_size()
+
+        self.sprite = Sprite(pyglet.resource.animation('dinosaur.gif'))
+        self.sprite.position = x//2, y//2
+        self.add( self.sprite  )
+
+def main():
     director.init()
     test_layer = TestLayer ()
     main_scene = cocos.scene.Scene (test_layer)
     director.run (main_scene)
+
+if __name__ == '__main__':
+    main()
