@@ -1,30 +1,42 @@
+from __future__ import division, print_function, unicode_literals
+
 # This code is so you can run the samples without installing the package
 import sys
 import os
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
 #
 
+testinfo = "t 0.1, s, t 1, s, t 2, s, t 3, s, t 4.1, s, q"
+tags = "Reverse"
 
 import cocos
 from cocos.director import director
 from cocos.actions import *
 from cocos.layer import *
 import pyglet
+from pyglet import gl
 
-class BackgroundLayer( cocos.layer.Layer ):
+class BackgroundLayer(cocos.layer.Layer):
     def __init__(self):
-        super( BackgroundLayer, self ).__init__()
+        super(BackgroundLayer, self).__init__()
         self.img = pyglet.resource.image('background_image.png')
 
     def draw( self ):
+        gl.glColor4ub(255, 255, 255, 255)
+        gl.glPushMatrix()
+        self.transform()
         self.img.blit(0,0)
+        gl.glPopMatrix()
 
-if __name__ == "__main__":
+def main():
     director.init( resizable=True )
     main_scene = cocos.scene.Scene()
 
     main_scene.add( BackgroundLayer(), z=0 )
 
     flip = FlipX3D( duration=2)
-    main_scene.do( flip + ReverseTime(flip) )
+    main_scene.do( flip + Reverse(flip) )
     director.run (main_scene)
+
+if __name__ == '__main__':
+    main()
