@@ -1,9 +1,13 @@
+from __future__ import division, print_function, unicode_literals
+
 # This code is so you can run the samples without installing the package
 import sys
 import os
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
 #
 
+testinfo = "t 0.1, s, t 2, s, t 5.1, s, t 5.2, s, q"
+tags = "sequence, MoveBy, Hide"
 
 import cocos
 from cocos.director import director
@@ -15,16 +19,23 @@ import pyglet
 class TestLayer(cocos.layer.Layer):
     def __init__(self):
         super( TestLayer, self ).__init__()
-        
-        x,y = director.get_window_size()
-        
-        self.sprite = Sprite( 'grossini.png', (0,y/2)  )
-        self.add( self.sprite )
-        self.sprite.do( MoveBy( (x/2, 0) ) + Hide() )
-        
 
-if __name__ == "__main__":
+        x,y = director.get_window_size()
+
+        self.sprite = Sprite( 'grossini.png', (0,y//2)  )
+        self.add( self.sprite )
+        self.sprite.do( MoveBy( (x//2, 0) ) + Hide() )
+
+description = """
+sprite moves to midscreen and then hides
+"""
+
+def main():
+    print(description)
     director.init()
     test_layer = TestLayer ()
     main_scene = cocos.scene.Scene (test_layer)
     director.run (main_scene)
+
+if __name__ == '__main__':
+    main()
