@@ -1,9 +1,13 @@
+from __future__ import division, print_function, unicode_literals
+
 # This code is so you can run the samples without installing the package
 import sys
 import os
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
 #
 
+testinfo = "t 0.1, s, t 0.5, s, t 1, s, t 1.5, s, t 2.1, s, q"
+tags = "ZoomTransition"
 
 import cocos
 from cocos.director import director
@@ -14,12 +18,13 @@ from cocos.sprite import *
 import pyglet
 from pyglet.gl import *
 
-class BackgroundLayer( cocos.layer.Layer ):
+class BackgroundLayer(cocos.layer.Layer):
     def __init__(self):
-        super( BackgroundLayer, self ).__init__()
+        super(BackgroundLayer, self).__init__()
         self.img = pyglet.resource.image('background_image.png')
 
     def draw( self ):
+        glColor4ub(255, 255, 255, 255)
         glPushMatrix()
         self.transform()
         self.img.blit(0,0)
@@ -31,8 +36,7 @@ def change_scene():
     scene1.add( BackgroundLayer(), z=0 )
     director.replace( ZoomTransition(scene1, 2) )
 
-
-if __name__ == "__main__":
+def main():
     director.init( resizable=True )
     scene2 = cocos.scene.Scene()
 
@@ -41,5 +45,8 @@ if __name__ == "__main__":
     colorl.add( sprite )
 
     scene2.add( colorl, z=0 )
-    scene2.do(Delay(1) + CallFunc(change_scene))
+    scene2.do(Delay(0.05) + CallFunc(change_scene))
     director.run(scene2)
+
+if __name__ == '__main__':
+    main()
